//
//  AnimateQueue.m
//  AnimateQueueSample
//
//  Created by Derek on 7/8/13.
//  Copyright (c) 2013 Derek. All rights reserved.
//

#import "AnimationQueue.h"


@implementation Animation
- (id)init:(NSTimeInterval)duration delay:(NSTimeInterval)delay options:(UIViewAnimationOptions)options animations:(void (^)(void))animations completion:(void (^)(void))completion{
	self = [super init];
	if (self) {
		self.anmiations = animations;
        self.completion = completion;
        self.duration = duration;
        self.delay = delay;
        self.options = options;
	}
	return self;
}


- (void)start {
	[UIView animateWithDuration:_duration delay:_delay options:_options animations:self.anmiations completion: ^(BOOL finished) {
	    if (self.completion) {
	        self.completion();
		}
	    if (self.next) {
	        self.next();
		}
	}];
}

@end
@interface AnimationQueue (Private)
@end
@implementation AnimationQueue
- (id)init {
	self = [super init];
	if (self) {
		_queue = [[NSMutableArray alloc] init];
	}
	return self;
}

- (void)addAnimation:(NSTimeInterval)duration delay:(NSTimeInterval)delay options:(UIViewAnimationOptions)options animations:(void (^)(void))animations completion:(void (^)(void))completion {
	Animation *animate = [[Animation alloc] init:duration delay:delay options:options animations:animations completion:completion];
	[_queue addObject:animate];
}

- (void)addAnimation:(NSTimeInterval)duration animations:(void (^)(void))animations completion:(void (^)(void))completion {
	[self addAnimation:duration delay:0 options:UIViewAnimationOptionCurveEaseInOut animations:animations completion:completion];
}

- (void)addAnimation:(NSTimeInterval)duration animations:(void (^)(void))animations {
	[self addAnimation:duration delay:0 options:UIViewAnimationOptionCurveEaseInOut animations:animations completion:nil];
}

- (void)start {
	for (int i = 0; i < [_queue count]-1; i++) {
		Animation *animate = [_queue objectAtIndex:i];
        
		Animation *nextAnimate = [_queue objectAtIndex:i + 1];
        [animate setNext:^{
            _currentAnimation = nextAnimate;
            [nextAnimate start];
        }];
	}
	Animation *firstAnimate = [_queue objectAtIndex:0];
	[firstAnimate start];
}



- (void)clear {
	[_queue removeAllObjects];
}

@end
